@@ -1,4 +1,4 @@
-#     Copyright 2014, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -15,22 +15,22 @@
 #     See the License for the specific language governing permissions and
 #     limitations under the License.
 #
-""" The virtue of importing modules and packages.
+""" Locating modules and package source on disk.
 
-The actual import of a module may already execute code that changes things.
+The actual import of a module would already execute code that changes things.
 Imagine a module that does "os.system()", it will be done. People often connect
 to databases, and these kind of things, at import time. Not a good style, but
 it's being done.
 
 Therefore CPython exhibits the interfaces in an "imp" module in standard
 library, which one can use those to know ahead of time, what file import would
-load. For us unfortunately there is nothing in CPython that is easily accessible
-and gives us this functionality for packages and search paths exactly like
-CPython does, so we implement here a multi step search process that is
+load. For us unfortunately there is nothing in CPython that gives the fully
+compatible functionality we need for packages and search paths exactly like
+CPython does, so we implement here a multiple step search process that is
 compatible.
 
 This approach is much safer of course and there is no loss. To determine if it's
-from the standard library, one can abuse the attribute "__file__" of the "os"
+from the standard library, we can abuse the attribute "__file__" of the "os"
 module like it's done in "isStandardLibraryPath" of this module.
 
 """
@@ -42,7 +42,7 @@ import os
 import sys
 from logging import warning
 
-from . import Utils
+from . import Utils, oset
 
 _debug_module_finding = False
 
@@ -52,12 +52,22 @@ warned_about = set()
 main_path = None
 
 def setMainScriptDirectory(main_dir):
+    """ Initialize the main script directory.
+
+        We use this as part of the search path for modules.
+    """
     # We need to set this from the outside, pylint: disable=W0603
 
     global main_path
     main_path = main_dir
 
 def isPackageDir(dirname):
+    """ Decide if a directory is a package.
+
+        Before Python3.3 it's required to have a "__init__.py" file, but then
+        it became impossible to decide.
+    """
+
     return Utils.isDir(dirname) and \
            (
                Utils.python_version >= 330 or
@@ -65,11 +75,20 @@ def isPackageDir(dirname):
            )
 
 def findModule(source_ref, module_name, parent_package, level, warn):
+    """ Find a module with given package name as parent.
+
+        The package name can be None of course. Level is the same
+        as with "__import__" built-in. Warnings are optional.
+
+        Returns a triple of package name the module is in, module name
+        and filename of it, which can be a directory.
+    """
+
     # We have many branches here, because there are a lot of cases to try.
     # pylint: disable=R0912
 
     if level > 1 and parent_package is not None:
-        parent_package = ".".join(parent_package.split(".")[:-level+1])
+        parent_package = '.'.join(parent_package.split('.')[:-level+1])
 
         if parent_package == "":
             parent_package = None
@@ -113,15 +132,15 @@ def findModule(source_ref, module_name, parent_package, level, warn):
                         )
 
 
-            if "." in module_name:
-                module_package_name = module_name[:module_name.rfind(".")]
+            if '.' in module_name:
+                module_package_name = module_name[:module_name.rfind('.')]
             else:
                 module_package_name = None
 
             module_filename = None
     else:
-        if "." in module_name:
-            module_package_name = module_name[:module_name.rfind(".")]
+        if '.' in module_name:
+            module_package_name = module_name[:module_name.rfind('.')]
         else:
             module_package_name = None
 
@@ -137,44 +156,98 @@ def findModule(source_ref, module_name, parent_package, level, warn):
 
     return module_package_name, module_name, module_filename
 
-def _impFindModuleWrapper(module_name, search_path):
-    """ This wraps imp.find_module because Python3.3 bugs.
+# Some platforms are case insensitive.
+case_sensitive = not sys.platform.startswith(("win", "cygwin", "darwin"))
 
-    Python3.3 accepts imports on directory names in PYTHONPATH, but does not
-    return them from imp.find_module, which it also deprecated, but would be
-    asking us to use the many variants in importlib manually. So this only
-    fixes up the one issue it has, that it won't accept these namespace dirs.
+def _findModuleInPath2(module_name, search_path):
+    """ This is out own module finding low level implementation.
 
-    TODO: That probably is not sufficient to cover actual namespace packages,
-    where multiple such directories are to be logically joined.
+        Just the full module name and search path are given. This is then
+        tasked to raise ImportError or return a path if it finds it, or
+        None, if it is a built-in.
     """
-    try:
-        # Does not accept keyword arguments, another thing this wrapper gives
-        # us then.
-        module_fh, module_filename, _module_desc = imp.find_module(
-            module_name,
-            search_path
-        )
-    except ImportError:
-        if Utils.python_version >= 330:
-            for path_element in search_path:
-                candidate = Utils.joinpath(path_element, module_name)
+    # We have many branches here, because there are a lot of cases to try.
+    # pylint: disable=R0912
 
-                if Utils.isDir(candidate):
-                    module_filename = candidate
-                    module_fh = None
+    if imp.is_builtin(module_name):
+        return None
 
+    # We may have to decide between package and module, therefore build
+    # a list of candidates.
+    candidates = oset.OrderedSet()
+
+    considered = set()
+
+    for entry in search_path:
+        # Don't try again, just with an entry of different casing or complete
+        # duplicate.
+        if Utils.normcase(entry) in considered:
+            continue
+        considered.add(Utils.normcase(entry))
+
+        package_directory = os.path.join(entry, module_name)
+
+        # First, check for a package with an init file, that would be the
+        # first choice.
+        if Utils.isDir(package_directory):
+            for suffix in (".py", ".pyc"):
+                package_file_name = "__init__" + suffix
+
+                file_path = os.path.join(package_directory, package_file_name)
+
+                if Utils.isFile(file_path):
+                    candidates.add(
+                        (entry, 1, package_directory)
+                    )
                     break
             else:
-                raise
+                if Utils.python_version >= 330:
+                    candidates.add(
+                        (entry, 2, package_directory)
+                    )
+
+        # Then, check out suffixes of all kinds.
+        for suffix, _mode, _type in imp.get_suffixes():
+            file_path = Utils.joinpath(entry, module_name + suffix)
+            if Utils.isFile(file_path):
+                candidates.add(
+                    (entry, 1, file_path)
+                )
+                break
+
+    if candidates:
+        # Ignore lower priority matches, package directories without init.
+        min_prio = min(candidate[1] for candidate in candidates)
+        candidates = [
+            candidate
+            for candidate in
+            candidates
+            if candidate[1] == min_prio
+        ]
+
+        # On case sensitive systems, no resolution needed.
+        if case_sensitive:
+            return candidates[0][2]
         else:
-            raise
+            if len(candidates) == 1:
+                # Just one finding, good.
+                return candidates[0][2]
+            else:
+                for candidate in candidates:
+                    dir_listing = os.listdir(candidate[0])
 
-    # Close the file handle, we won't use it.
-    if module_fh is not None:
-        module_fh.close()
+                    for filename in dir_listing:
+                        if Utils.joinpath(candidate[0], filename) == candidate[2]:
+                            return candidate[2]
 
-    return module_filename
+                # Please report this, but you may uncomment and have luck.
+                assert False, candidates
+
+                # If no case matches, just pick the first.
+                return candidates[0][2]
+
+    # Nothing found.
+    raise ImportError
 
 
 def _findModuleInPath(module_name, package_name):
@@ -188,15 +261,15 @@ def _findModuleInPath(module_name, package_name):
     extra_paths = [os.getcwd(), main_path]
 
     if package_name is not None:
-        # Work around imp.find_module bug on at least Windows. Won't handle
+        # Work around _findModuleInPath2 bug on at least Windows. Won't handle
         # module name empty in find_module. And thinking of it, how could it
         # anyway.
         if module_name == "":
-            module_name = package_name.split(".")[-1]
-            package_name = ".".join(package_name.split(".")[:-1])
+            module_name = package_name.split('.')[-1]
+            package_name = '.'.join(package_name.split('.')[:-1])
 
         def getPackageDirnames(element):
-            yield Utils.joinpath(element,*package_name.split(".")), False
+            yield Utils.joinpath(element,*package_name.split('.')), False
 
             if package_name == "win32com":
                 yield Utils.joinpath(element,"win32comext"), True
@@ -211,14 +284,14 @@ def _findModuleInPath(module_name, package_name):
             print("_findModuleInPath: Package, using extended path", ext_path)
 
         try:
-            module_filename = _impFindModuleWrapper(
+            module_filename = _findModuleInPath2(
                 module_name = module_name,
                 search_path = ext_path
             )
 
             if _debug_module_finding:
                 print(
-                    "_findModuleInPath: imp.find_module worked",
+                    "_findModuleInPath: _findModuleInPath2 worked",
                     module_filename,
                     package_name
                 )
@@ -226,7 +299,7 @@ def _findModuleInPath(module_name, package_name):
             return module_filename, package_name
         except ImportError:
             if _debug_module_finding:
-                print("_findModuleInPath: imp.find_module failed to locate")
+                print("_findModuleInPath: _findModuleInPath2 failed to locate")
         except SyntaxError:
             # Warn user, as this is kind of unusual.
             warning(
@@ -242,7 +315,7 @@ def _findModuleInPath(module_name, package_name):
         print("_findModuleInPath: Non-package, using extended path", ext_path)
 
     try:
-        module_filename = _impFindModuleWrapper(
+        module_filename = _findModuleInPath2(
             module_name = module_name,
             search_path = ext_path
         )
@@ -256,7 +329,7 @@ def _findModuleInPath(module_name, package_name):
         return None, None
 
     if _debug_module_finding:
-        print("_findModuleInPath: imp.find_module gave", module_filename)
+        print("_findModuleInPath: _findModuleInPath2 gave", module_filename)
 
     return module_filename, None
 
@@ -265,7 +338,7 @@ def _findModule(module_name, parent_package):
     if _debug_module_finding:
         print("_findModule: Enter", module_name, "in", parent_package)
 
-    # The os.path is strangely hacked into the os module, dispatching per
+    # The os.path is strangely hacked into the "os" module, dispatching per
     # platform, we either cannot look into it, or we require that we resolve it
     # here correctly.
     if module_name == "os.path" and parent_package is None:
@@ -281,16 +354,16 @@ def _findModule(module_name, parent_package):
     if module_name in sys.builtin_module_names and parent_package is None:
         return None, None
 
-    if "." in module_name:
-        package_part = module_name[ : module_name.rfind(".") ]
-        module_name = module_name[ module_name.rfind(".") + 1 : ]
+    if '.' in module_name:
+        package_part = module_name[ : module_name.rfind('.') ]
+        module_name = module_name[ module_name.rfind('.') + 1 : ]
 
         # Relative import
         if parent_package is not None:
             try:
                 return _findModule(
                     module_name    = module_name,
-                    parent_package = parent_package + "." + package_part
+                    parent_package = parent_package + '.' + package_part
                 )
             except ImportError:
                 pass
@@ -336,9 +409,22 @@ def getModuleWhiteList():
         # CPython3 does these:
         "builtins", "UserDict", "os.path", "StringIO",
 
+        # test_applesingle.py
+        "applesingle",
+
+        # test_compile.py
+        "__package__.module", "__mangled_mod",
+
         # test_dbm.py
         "dbm.dumb",
 
+        # test_distutils.py
+        "distutils.tests", "distutils.mwerkscompiler",
+
+        # test_emails.py
+        "email.test.test_email", "email.test.test_email_renamed",
+        "email.test.test_email_codecs",
+
         # test/test_dbm_ndbm.py
         "dbm.ndbm",
 
@@ -349,7 +435,8 @@ def getModuleWhiteList():
         "importlib.test.import_", "pep3147.foo", "pep3147",
 
         # test_import.py
-        "RAnDoM", "infinite_reload", "test_trailing_slash",
+        "RAnDoM", "infinite_reload", "test_trailing_slash", "nonexistent_xyzzy",
+        "_parent_foo.bar", "_parent_foo", "test_unc_path",
 
         # test_importhooks.py
         "hooktestmodule", "hooktestpackage", "hooktestpackage.sub",
@@ -360,19 +447,40 @@ def getModuleWhiteList():
         # test_inspect.py
         "inspect_fodder3",
 
+        # test_imageop.py
+        "imgfile",
+
+        # test_json.py
+        "json.tests",
+
+        # test_lib2to3.py
+        "lib2to3.tests",
+
+        # test_logging.py
+        "win32evtlog", "win32evtlogutil",
+
+        # test_macostools.py
+        "macostools",
+
+        # test_namespace_pkgs.py
+        "foo.one", "foo.two", "parent.child.one", "parent.child.two",
+        "parent.child.three", "bar.two", "a_test",
+
         # test_new.py
         "Spam",
-
-        # test_pkg.py
-        "t1", "t2", "t2.sub", "t2.sub.subsub", "t3.sub.subsub", "t5", "t6",
-        "t7", "t7.sub", "t7.sub.subsub",
-
-        # test_pkgutil.py
-        "foo", "zipimport",
+        # est_ossaudiodev.py
+        "ossaudiodev",
 
         # test_platform.py
         "gestalt",
 
+        # test_pkg.py
+        "t1", "t2", "t2.sub", "t2.sub.subsub", "t3.sub.subsub", "t5", "t6",
+        "t7", "t7.sub", "t7.sub.subsub", "t8",
+
+        # test_pkgutil.py
+        "foo", "zipimport",
+
         # test_repr.py
         """areallylongpackageandmodulenametotestreprtruncation.\
 areallylongpackageandmodulenametotestreprtruncation""",
@@ -389,40 +497,21 @@ areallylongpackageandmodulenametotestreprtruncation""",
         # test_strop.py
         "strop",
 
-        # test_applesingle.py
-        "applesingle",
-
-        # test_compile.py
-        "__package__.module", "__mangled_mod",
-
-        # test_distutils.py
-        "distutils.tests", "distutils.mwerkscompiler",
-
-        # test_emails.py
-        "email.test.test_email", "email.test.test_email_renamed",
-        "email.test.test_email_codecs",
-
-        # test_imageop.py
-        "imgfile",
-
-        # test_json.py
-        "json.tests",
-
-        # test_lib2to3.py
-        "lib2to3.tests",
-
-        # test_macostools.py
-        "macostools",
-
-        # test_pkg.py
-        "t8",
+        # test_sundry.py
+        "distutils.emxccompiler", "os2emxpath",
 
         # test_tk.py
         "runtktests",
 
+        # test_tools.py
+        "analyze_dxp", "test_unparse",
+
         # test_traceback.py
         "test_bug737473",
 
+        # test_xml_etree.py
+        "xml.parsers.expat.errors",
+
         # test_zipimport_support.py
         "test_zipped_doctest", "zip_pkg",
 
@@ -446,14 +535,18 @@ areallylongpackageandmodulenametotestreprtruncation""",
         "comtypes.server.inprocserver", "_tkinter", "_scproxy", "EasyDialogs",
         "SOCKS", "rourl2path", "_winapi", "win32api", "win32con", "_gestalt",
         "java.lang", "vms_lib", "ic", "readline", "termios", "_sysconfigdata",
-        "al", "AL", "sunaudiodev", "SUNAUDIODEV", "Audio_mac",
+        "al", "AL", "sunaudiodev", "SUNAUDIODEV", "Audio_mac", "nis",
         "test.test_MimeWriter", "dos", "win32pipe", "Carbon", "Carbon.Files",
         "sgi", "ctypes.macholib.dyld", "bsddb3", "_pybsddb", "_xmlrpclib",
         "netbios", "win32wnet", "email.Parser", "elementree.cElementTree",
-        "elementree.ElementTree", "_gbdm",
+        "elementree.ElementTree", "_gbdm", "resource", "crypt", "bz2", "dbm",
+        "mmap",
 
         # Nuitka tests
-        "test_common"
+        "test_common",
+
+        # Mercurial test
+        "statprof", "email.Generator", "email.Utils",
     )
 
 def _isWhiteListedNotExistingModule(module_name):
@@ -468,6 +561,9 @@ please report this to http://bugs.nuitka.net.""", module_name)
 
 
 def getStandardLibraryPaths():
+    """ Get the standard library paths.
+
+    """
 
     # Using the function object to cache its result, avoiding global variable
     # usage.
@@ -493,7 +589,7 @@ def getStandardLibraryPaths():
         if Utils.isFile(orig_prefix_filename):
             # Scan upwards, until we find a "bin" folder, with "activate" to
             # locate the structural path to be added. We do not know for sure
-            # if there is a subdirectory under lib to use or not. So we try
+            # if there is a sub-directory under "lib" to use or not. So we try
             # to detect it.
             search = os_path
             lib_part = ""
@@ -541,6 +637,10 @@ def getStandardLibraryPaths():
 
 
 def isStandardLibraryPath(path):
+    """ Check if a path is in the standard library.
+
+    """
+
     path = Utils.normcase(path)
 
     # In virtualenv, the "site.py" lives in a place that suggests it is not in
