@@ -1,4 +1,4 @@
-#     Copyright 2014, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -32,7 +32,6 @@ from . import (
     Importing,
     ModuleRegistry,
     Options,
-    PythonVersions,
     SyntaxErrors,
     Tracing,
     TreeXML,
@@ -205,35 +204,47 @@ def pickSourceFilenames(source_dir, modules):
     collision_filenames = set()
     seen_filenames = set()
 
-    for module in sorted(modules, key = lambda x : x.getFullName()):
-        base_filename = Utils.joinpath(source_dir, module.getFullName())
-
-        # Note: Could detect if the filesystem is cases sensitive in source_dir
-        # or not, but that's probably not worth the effort.
-        collision_filename = Utils.normcase(base_filename)
-
-        if collision_filename in seen_filenames:
-            collision_filenames.add(collision_filename)
-
-        seen_filenames.add(collision_filename)
-
-    collision_counts = {}
-
+    # Our output.
     module_filenames = {}
 
-    for module in sorted(modules, key = lambda x : x.getFullName()):
-        if module.isPythonShlibModule():
-            continue
-
-        base_filename = Utils.joinpath(
+    def getFilenames(module):
+        base_filename =  Utils.joinpath(
             source_dir,
             "module." + module.getFullName()
               if not module.isInternalModule() else
             module.getFullName()
         )
 
+        # Note: Could detect if the file system is cases sensitive in source_dir
+        # or not, but that's probably not worth the effort. False positives do
+        # no harm at all.
         collision_filename = Utils.normcase(base_filename)
 
+        return base_filename, collision_filename
+
+    # First pass, check for collisions.
+    for module in modules:
+        if module.isPythonShlibModule():
+            continue
+
+        base_filename = base_filename, collision_filename = getFilenames(module)
+
+        if collision_filename in seen_filenames:
+            collision_filenames.add(collision_filename)
+
+        seen_filenames.add(collision_filename)
+
+    # Count up for colliding filenames.
+    collision_counts = {}
+
+    # Second pass, this time sorted, so we get determistic results. We will
+    # apply an @1/@2 to disambiguate the filenames.
+    for module in sorted(modules, key = lambda x : x.getFullName()):
+        if module.isPythonShlibModule():
+            continue
+
+        base_filename = base_filename, collision_filename = getFilenames(module)
+
         if collision_filename in collision_filenames:
             collision_counts[ collision_filename ] = \
               collision_counts.get(collision_filename, 0) + 1
@@ -344,7 +355,7 @@ def makeSourceDirectory(main_module):
         elif module.isPythonShlibModule():
             target_filename = Utils.joinpath(
                 getStandaloneDirectoryPath(main_module),
-                *module.getFullName().split(".")
+                *module.getFullName().split('.')
             )
 
             if Utils.getOS() == "Windows":
@@ -370,7 +381,7 @@ def makeSourceDirectory(main_module):
 
     writeSourceCode(
         filename    = Utils.joinpath(source_dir, "__constants.cpp"),
-        source_code = CodeGeneration.generateConstantsDefinitionCode(
+        source_code = ConstantCodes.getConstantsDefinitionCode(
             context = global_context
         )
     )
@@ -397,10 +408,10 @@ def runScons(main_module, quiet):
     if hasattr(sys, "abiflags"):
         if Options.isPythonDebug() or \
            hasattr(sys, "getobjects"):
-            if sys.abiflags.startswith("d"):
+            if sys.abiflags.startswith('d'):
                 python_version += sys.abiflags
             else:
-                python_version += "d" + sys.abiflags
+                python_version += 'd' + sys.abiflags
         else:
             python_version += sys.abiflags
 
@@ -458,7 +469,7 @@ def runScons(main_module, quiet):
         msvc_version = Options.getMsvcVersion()
 
         msvc_version = msvc_version.replace("exp", "Exp")
-        if "." not in msvc_version:
+        if '.' not in msvc_version:
             msvc_version += ".0"
 
         options["msvc_version"] = msvc_version
@@ -481,7 +492,7 @@ def writeSourceCode(filename, source_code):
         with open(filename, "wb") as output_file:
             output_file.write(source_code.encode("latin1"))
     else:
-        with open(filename, "w") as output_file:
+        with open(filename, 'w') as output_file:
             output_file.write(source_code)
 
 
@@ -504,7 +515,7 @@ def callExec(args, clean_path, add_path):
 
     if add_path:
         if "PYTHONPATH" in os.environ:
-            os.environ["PYTHONPATH"] += ":" + Options.getOutputDir()
+            os.environ["PYTHONPATH"] += ':' + Options.getOutputDir()
         else:
             os.environ["PYTHONPATH"] = Options.getOutputDir()
 
@@ -595,7 +606,7 @@ def compileTree(main_module):
 
     if Options.isShowProgress():
         Tracing.printLine(
-            """Total memory usage before running scons: {memory}:""".format(
+            "Total memory usage before running scons: {memory}:".format(
                 memory = Utils.getHumanReadableProcessMemoryUsage()
             )
         )
@@ -659,22 +670,7 @@ def main():
             filename = filename
         )
     except (SyntaxError, IndentationError) as e:
-        if Options.isFullCompat() and \
-           (e.args[0].startswith("unknown encoding:") or \
-            e.args[0].startswith("encoding problem:")):
-            if PythonVersions.doShowUnknownEncodingName():
-                complaint = e.args[0].split(":",2)[1]
-            else:
-                complaint = " with BOM"
-
-            e.args = (
-                "encoding problem:%s" % complaint,
-                (e.args[1][0], 1, None, None)
-            )
-
-            if hasattr(e, "msg"):
-                e.msg = e.args[0]
-
+        # Syntax or indentation errors, output them to the user and abort.
         sys.exit(
             SyntaxErrors.formatOutput(e)
         )
