@@ -1,4 +1,4 @@
-#     Copyright 2014, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -114,7 +114,7 @@ class ExpressionBuiltinIntLongBase(ChildrenHavingMixin, NodeBase,
 
         if value is None and self.base_only_value:
             value = makeConstantReplacementNode(
-                constant = "0",
+                constant = '0',
                 node     = self
             )
 
