@@ -1,4 +1,4 @@
-#     Copyright 2014, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -71,19 +71,19 @@ class FutureSpec:
     def asFlags(self):
         result = []
 
-        if self.future_division:
+        if self.future_division and Utils.python_version < 300:
             result.append("CO_FUTURE_DIVISION")
 
         if self.unicode_literals:
             result.append("CO_FUTURE_UNICODE_LITERALS")
 
-        if self.absolute_import:
+        if self.absolute_import and Utils.python_version < 300:
             result.append("CO_FUTURE_ABSOLUTE_IMPORT")
 
-        if self.future_print:
+        if self.future_print and Utils.python_version < 300:
             result.append("CO_FUTURE_PRINT_FUNCTION")
 
         if self.barry_bdfl and Utils.python_version >= 300:
             result.append("CO_FUTURE_BARRY_AS_BDFL")
 
-        return result
+        return tuple(result)
