@@ -1,4 +1,4 @@
-#     Copyright 2014, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -152,6 +152,7 @@ def getComputationResult(node, computation, description):
 
     return new_node, change_tags, change_desc
 
+
 def makeStatementExpressionOnlyReplacementNode(expression, node):
     return StatementExpressionOnly(
         expression = expression,
@@ -253,23 +254,30 @@ def makeStatementOnlyNodesFromExpressions(expressions):
             source_ref = statements[0].getSourceReference()
         )
 
+
 def makeComparisonNode(left, right, comparator, source_ref):
     if comparator == "Is":
-        return ExpressionComparisonIs(
+        result = ExpressionComparisonIs(
             left       = left,
             right      = right,
             source_ref = source_ref
         )
     elif comparator == "IsNot":
-        return ExpressionComparisonIsNOT(
+        result = ExpressionComparisonIsNOT(
                 left       = left,
                 right      = right,
                 source_ref = source_ref
             )
     else:
-        return ExpressionComparison(
+        result = ExpressionComparison(
             left       = left,
             right      = right,
             comparator = comparator,
             source_ref = source_ref
         )
+
+    result.setCompatibleSourceReference(
+        source_ref = right.getCompatibleSourceReference()
+    )
+
+    return result
