@@ -1,4 +1,4 @@
-#     Copyright 2014, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -23,7 +23,7 @@
 import ast
 from logging import warning
 
-from nuitka import Constants, Options, Tracing
+from nuitka import Constants, Tracing
 from nuitka.nodes.ConstantRefNodes import ExpressionConstantRef
 from nuitka.nodes.ContainerMakingNodes import (
     ExpressionKeyValuePair,
@@ -46,7 +46,7 @@ def dump(node):
 
 
 def getKind(node):
-    return node.__class__.__name__.split(".")[-1]
+    return node.__class__.__name__.split('.')[-1]
 
 
 def extractDocFromBody(node):
@@ -306,9 +306,6 @@ def makeSequenceCreationOrConstant(sequence_kind, elements, source_ref):
 
     sequence_kind = sequence_kind.upper()
 
-    if Options.isFullCompat() and elements:
-        source_ref = elements[-1].getSourceReference()
-
     # Note: This would happen in optimization instead, but lets just do it
     # immediately to save some time.
     if constant:
@@ -321,7 +318,7 @@ def makeSequenceCreationOrConstant(sequence_kind, elements, source_ref):
         else:
             assert False, sequence_kind
 
-        return ExpressionConstantRef(
+        result = ExpressionConstantRef(
             constant      = const_type(
                 element.getConstant()
                 for element in
@@ -332,23 +329,30 @@ def makeSequenceCreationOrConstant(sequence_kind, elements, source_ref):
         )
     else:
         if sequence_kind == "TUPLE":
-            return ExpressionMakeTuple(
+            result = ExpressionMakeTuple(
                 elements   = elements,
                 source_ref = source_ref
             )
         elif sequence_kind == "LIST":
-            return ExpressionMakeList(
+            result = ExpressionMakeList(
                 elements   = elements,
                 source_ref = source_ref
             )
         elif sequence_kind == "SET":
-            return ExpressionMakeSet(
+            result = ExpressionMakeSet(
                 elements   = elements,
                 source_ref = source_ref
             )
         else:
             assert False, sequence_kind
 
+    if elements:
+        result.setCompatibleSourceReference(
+            source_ref = elements[-1].getCompatibleSourceReference()
+        )
+
+    return result
+
 
 def makeDictCreationOrConstant(keys, values, lazy_order, source_ref):
     # Create dictionary node. Tries to avoid it for constant values that are not
@@ -366,16 +370,13 @@ def makeDictCreationOrConstant(keys, values, lazy_order, source_ref):
     else:
         constant = True
 
-    if Options.isFullCompat() and values:
-        source_ref = values[-1].getSourceReference()
-
     # Note: This would happen in optimization instead, but lets just do it
     # immediately to save some time.
     if constant:
         # Unless told otherwise, create the dictionary in its full size, so
         # that no growing occurs and the constant becomes as similar as possible
         # before being marshaled.
-        return ExpressionConstantRef(
+        result = ExpressionConstantRef(
             constant      = Constants.createConstantDict(
                 lazy_order = not lazy_order,
                 keys       = [
@@ -393,7 +394,7 @@ def makeDictCreationOrConstant(keys, values, lazy_order, source_ref):
             user_provided = True
         )
     else:
-        return ExpressionMakeDict(
+        result = ExpressionMakeDict(
             pairs      = [
                 ExpressionKeyValuePair(
                     key        = key,
@@ -407,6 +408,13 @@ def makeDictCreationOrConstant(keys, values, lazy_order, source_ref):
             source_ref = source_ref
         )
 
+    if values:
+        result.setCompatibleSourceReference(
+            source_ref = values[-1].getCompatibleSourceReference()
+        )
+
+    return result
+
 
 def makeTryFinallyStatement(tried, final, source_ref):
     if type(tried) in (tuple, list):
@@ -457,6 +465,24 @@ def makeTryFinallyExpression(expression, tried, final, source_ref):
         source_ref = source_ref
     )
 
+
+def mangleName(variable_name, owner):
+    if not variable_name.startswith("__") or variable_name.endswith("__"):
+        return variable_name
+    else:
+        # The mangling of function variable names depends on being inside a
+        # class.
+        class_container = owner.getContainingClassDictCreation()
+
+        if class_container is None:
+            return variable_name
+        else:
+            return "_%s%s" % (
+                class_container.getName().lstrip('_'),
+                variable_name
+            )
+
+
 build_contexts = [None]
 
 def pushBuildContext(value):
