@@ -1,4 +1,4 @@
-#     Copyright 2014, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -61,7 +61,7 @@ from .ReformulationFunctionStatements import (
 def buildLambdaNode(provider, node, source_ref):
     assert getKind(node) == "Lambda"
 
-    parameters = buildParameterSpec("<lambda>", node, source_ref)
+    parameters = buildParameterSpec(provider, "<lambda>", node, source_ref)
 
     function_body = ExpressionFunctionBody(
         provider   = provider,
