@@ -1,4 +1,4 @@
-#     Copyright 2014, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -23,95 +23,76 @@ and version differences of Python.
 
 import re
 
-from nuitka import SourceCodeReferences, SyntaxErrors, Utils
+from nuitka import (
+    Options,
+    PythonVersions,
+    SourceCodeReferences,
+    SyntaxErrors,
+    Utils
+)
 
 
 def _readSourceCodeFromFilename3(source_filename):
-    with open(source_filename, "rb") as source_file:
-        source_code = source_file.read()
+    import tokenize
 
-    if source_code.startswith(b'\xef\xbb\xbf'):
-        source_code = source_code[3:]
+    try:
+        with open(source_filename, "rb") as source_file:
+            encoding = tokenize.detect_encoding(source_file.readline)[0]
 
-    new_line = source_code.find(b"\n")
+            # Rewind to get the whole file.
+            source_file.seek(0)
 
-    if new_line is not -1:
-        line = source_code[: new_line]
+            source_code = source_file.read()
 
-        line_match = re.search(b"coding[:=]\\s*([-\\w.]+)", line)
+        return source_code.decode(encoding)
+    except SyntaxError as e:
+        if Options.isFullCompat():
+            if PythonVersions.doShowUnknownEncodingName():
+                match = re.match("unknown encoding for '.*?': (.*)", e.args[0])
+                complaint = match.group(1)
+            else:
+                complaint = "with BOM"
 
-        if line_match:
-            encoding = line_match.group(1).decode("ascii")
+            e.args = (
+                "encoding problem: %s" % complaint,
+                (source_filename, 1, None, None)
+            )
 
-            # Detect encoding problem, as decode won't raise the compatible
-            # thing.
-            try:
-                import codecs
-                codecs.lookup(encoding)
-            except LookupError:
-                if Utils.python_version >= 341 or \
-                   (Utils.python_version >= 335 and \
-                    Utils.python_version < 340) or \
-                   (Utils.python_version >= 323 and \
-                    Utils.python_version < 330):
-                    reason = "encoding problem: %s" % encoding
-                else:
-                    reason = "unknown encoding: %s" % encoding
+            if hasattr(e, "msg"):
+                e.msg = e.args[0]
 
-                SyntaxErrors.raiseSyntaxError(
-                    reason       = reason,
-                    source_ref   = SourceCodeReferences.fromFilename(
-                        source_filename,
-                        None
-                    ),
-                    display_line = False
-                )
+        raise
 
-            return source_code[ new_line : ].decode(encoding)
-
-        new_line = source_code.find(b"\n", new_line+1)
-
-        if new_line is not -1:
-            line = source_code[ : new_line ]
-
-            line_match = re.search(b"coding[:=]\\s*([-\\w.]+)", line)
-
-            if line_match:
-                encoding = line_match.group(1).decode("ascii")
-
-                return "\n" + source_code[ new_line : ].decode(encoding)
-
-    return source_code.decode("utf-8")
-
-def _detectEncoding2(source_filename):
+def _detectEncoding2(source_file):
     # Detect the encoding.
     encoding = "ascii"
 
-    with open(source_filename, "rb") as source_file:
-        line1 = source_file.readline()
+    line1 = source_file.readline()
 
-        if line1.startswith(b'\xef\xbb\xbf'):
-            encoding = "utf-8"
+    if line1.startswith(b'\xef\xbb\xbf'):
+        encoding = "utf-8"
+    else:
+        line1_match = re.search(b"coding[:=]\\s*([-\\w.]+)", line1)
+
+        if line1_match:
+            encoding = line1_match.group(1)
         else:
-            line1_match = re.search(b"coding[:=]\\s*([-\\w.]+)", line1)
+            line2 = source_file.readline()
 
-            if line1_match:
-                encoding = line1_match.group(1)
-            else:
-                line2 = source_file.readline()
+            line2_match = re.search(b"coding[:=]\\s*([-\\w.]+)", line2)
 
-                line2_match = re.search(b"coding[:=]\\s*([-\\w.]+)", line2)
+            if line2_match:
+                encoding = line2_match.group(1)
 
-                if line2_match:
-                    encoding = line2_match.group(1)
+    source_file.seek(0)
 
     return encoding
 
 def _readSourceCodeFromFilename2(source_filename):
     # Detect the encoding.
-    encoding = _detectEncoding2(source_filename)
-
     with open(source_filename, "rU") as source_file:
+        encoding = _detectEncoding2(source_file)
+
         source_code = source_file.read()
 
         # Try and detect SyntaxError from missing or wrong encodings.
@@ -119,7 +100,7 @@ def _readSourceCodeFromFilename2(source_filename):
             try:
                 _source_code = source_code.decode(encoding)
             except UnicodeDecodeError as e:
-                lines = source_code.split("\n")
+                lines = source_code.split('\n')
                 so_far = 0
 
                 for count, line in enumerate(lines):
