@@ -1,4 +1,4 @@
-#     Copyright 2014, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python tests originally created or extracted from other peoples work. The
 #     parts were too small to be protected.
@@ -21,12 +21,12 @@ b = 7
 c = [7, 8]
 d = 15
 
-print "+", a + b
-print "-", a - b
-print "*", a * b
-print "/", a / b
+print '+', a + b
+print '-', a - b
+print '*', a * b
+print '/', a / b
 print "//", a // b
-print "%", b % a
+print '%', b % a
 print "& (2)", a & b
 print "| (2)", a | b
 print "& (3)", a & b & d
@@ -38,8 +38,8 @@ print "<<", a << b
 print ">>", b >> a
 print "in", b in c
 print "not in", b not in c
-print "<", a < b
-print ">", a > b
+print '<', a < b
+print '>', a > b
 print "==", a == b
 print "<=", a <= b
 print ">=", a >= b
@@ -47,16 +47,16 @@ print "!=", a != b
 print "is", a is b
 print "is not", a is not b
 
-print "~", ~ b
-print "-", - b
-print "+", + b
+print '~', ~ b
+print '-', - b
+print '+', + b
 
-l =  {("a", "c") : "a,c", "b" : 2, "c" : 3, "d" : 4  }
-l[ "l", ] = "6"
+l =  {('a', 'c') : "a,c", 'b' : 2, 'c' : 3, 'd' : 4  }
+l[ 'l', ] = '6'
 
 
 print "Extended slicing:"
-print "Should be a,c:", l[ "a", "c"]
+print "Should be a,c:", l[ 'a', 'c']
 
 print "Short form of extended slicing:"
 
