@@ -1,4 +1,4 @@
-#     Copyright 2014, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python tests originally created or extracted from other peoples work. The
 #     parts were too small to be protected.
@@ -16,18 +16,29 @@
 #     limitations under the License.
 #
 
+# In this test we show that return in try/finally executes the finally part
+# just fine.
+
+from __future__ import print_function
+
+
+def eight():
+    return 8
+
+def nine():
+    return 9
 
 def returnInTried():
     try:
-        return 8
+        return eight()
     finally:
-        print "returnInTried",
+        print("returnInTried", end = ' ')
 
 def returnInFinally():
     try:
-        print "returnInFinally tried",
+        print("returnInFinally tried", end = ' ')
     finally:
-        return 9
+        return nine()
 
-print returnInTried()
-print returnInFinally()
+print(returnInTried())
+print(returnInFinally())
