@@ -1,4 +1,4 @@
-#     Copyright 2013, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python test originally created or extracted from other peoples work. The
 #     parts from me are licensed as below. It is at least Free Softwar where
@@ -17,5 +17,8 @@
 #     See the License for the specific language governing permissions and
 #     limitations under the License.
 #
-import pyexpat
-print( pyexpat.__doc__ )
+try:
+    import pyexpat
+    print(pyexpat.__doc__)
+except ImportError:
+    print("Skipped, no pyexpat module installed.")
